# -*- coding: utf-8 -*-

from flask import Flask, render_template
import spidev
import signal
import sys

# Flaskのインスタンスの作成
app = Flask(__name__)

# SPIのインスタンスの作成
spi = spidev.SpiDev()

# 「/」にアクセスしたときの処理
@app.route("/")
def index():
    # ch0
    resp = spi.xfer2([0x68, 0x00])
    value0 = ((resp[0] << 8) + resp[1]) & 0x3ff
    # ch1
    resp = spi.xfer2([0x78, 0x00])
    value1 = ((resp[0] << 8) + resp[1]) & 0x3ff
    # テンプレートを利用したレンダリング
    return render_template("index.html", ch0_value=value0, ch1_value=value1)

# 「Ctrl + C」による終了時の処理
def sigint_handler(signal, frame):
    app.logger.debug("Closing")
    spi.close()
    app.logger.debug("Closed")
    sys.exit(0)

# メイン関数
if __name__ == "__main__":
    # SIGINTハンドラの設定
    signal.signal(signal.SIGINT, sigint_handler)
    # SPIの初期化
    spi.open(0, 0)
    # Flaskインスタンス実行
    #app.run("0.0.0.0", debug=True) # デバッグ出力する実行
    app.run("0.0.0.0") # デバッグ出力しない実行
